HOWTO analyze performance
=========================

Intro
-----

* https://medium.com/netflix-techblog/linux-performance-analysis-in-60-000-milliseconds-accc10403c55


bcc tutorial
------------

* https://github.com/iovisor/bcc/blob/master/docs/tutorial.md


eBPF Tracing
------------

* http://www.brendangregg.com/blog/2019-01-01/learn-ebpf-tracing.html


perf examples
-------------

* http://www.brendangregg.com/perf.html
  
